@@ -57,11 +57,14 @@ import FreeCAD
 import Draft
 import DraftVecUtils
 from FreeCAD import Vector
+from draftutils import params
+from draftutils import utils
 from draftutils.translate import translate
-from draftutils.messages import _msg, _wrn, _err
+from draftutils.messages import _err, _msg, _wrn
+from builtins import open as pyopen
 
 if FreeCAD.GuiUp:
-    from PySide import QtGui
+    from PySide import QtWidgets
     import FreeCADGui
     gui = True
     try:
@@ -72,9 +75,7 @@ else:
     gui = False
     draftui = None
 
-# Save the native open function to avoid collisions
-if open.__module__ in ['__builtin__', 'io']:
-    pythonopen = open
+
 
 svgcolors = {
     'Pink': (255, 192, 203),
@@ -413,7 +414,7 @@ def getsize(length, mode='discard', base=1):
         }
 
     # Extract a number from a string like '+56215.14565E+6mm'
-    _num = '([-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?)'
+    _num = '([-+]?[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?)'
     _unit = '(px|pt|pc|mm|cm|in|em|ex|%)?'
     _full_num = _num + _unit
     number, exponent, unit = re.findall(_full_num, length)[0]
@@ -655,11 +656,8 @@ class svgHandler(xml.sax.ContentHandler):
     def __init__(self):
         super().__init__()
         """Retrieve Draft parameters and initialize."""
-        _prefs = "User parameter:BaseApp/Preferences/Mod/Draft"
-        params = FreeCAD.ParamGet(_prefs)
-        self.style = params.GetInt("svgstyle")
-        self.disableUnitScaling = params.GetBool("svgDisableUnitScaling",
-                                                 False)
+        self.style = params.get_param("svgstyle")
+        self.disableUnitScaling = params.get_param("svgDisableUnitScaling")
         self.count = 0
         self.transform = None
         self.grouptransform = []
@@ -674,16 +672,13 @@ class svgHandler(xml.sax.ContentHandler):
         import Part
 
         if gui and draftui:
-            r = float(draftui.color.red()/255.0)
-            g = float(draftui.color.green()/255.0)
-            b = float(draftui.color.blue()/255.0)
+            r = float(draftui.color.red() / 255.0)
+            g = float(draftui.color.green() / 255.0)
+            b = float(draftui.color.blue() / 255.0)
             self.lw = float(draftui.linewidth)
         else:
-            self.lw = float(params.GetInt("linewidth"))
-            c = params.GetUnsigned("color")
-            r = float(((c >> 24) & 0xFF)/255)
-            g = float(((c >> 16) & 0xFF)/255)
-            b = float(((c >> 8) & 0xFF)/255)
+            self.lw = float(params.get_param_view("DefaultShapeLineWidth"))
+            r, g, b, _ = utils.get_rgba_tuple(params.get_param_view("DefaultShapeLineColor"))
         self.col = (r, g, b, 0.0)
 
     def format(self, obj):
@@ -729,7 +724,7 @@ class svgHandler(xml.sax.ContentHandler):
             if 'inkscape:version' in data:
                 inks_doc_name = attrs.getValue('sodipodi:docname')
                 inks_full_ver = attrs.getValue('inkscape:version')
-                inks_ver_pars = re.search("\d+\.\d+", inks_full_ver)
+                inks_ver_pars = re.search("\\d+\\.\\d+", inks_full_ver)
                 if inks_ver_pars is not None:
                     inks_ver_f = float(inks_ver_pars.group(0))
                 else:
@@ -756,14 +751,14 @@ class svgHandler(xml.sax.ContentHandler):
                     _qst = ("Do you wish to use 96 dpi? Choosing 'No' "
                             "will use the older standard 90 dpi.")
                     if FreeCAD.GuiUp:
-                        msgBox = QtGui.QMessageBox()
+                        msgBox = QtWidgets.QMessageBox()
                         msgBox.setText(translate("ImportSVG", _inf))
                         msgBox.setInformativeText(translate("ImportSVG", _qst))
-                        msgBox.setStandardButtons(QtGui.QMessageBox.Yes
-                                                  | QtGui.QMessageBox.No)
-                        msgBox.setDefaultButton(QtGui.QMessageBox.No)
+                        msgBox.setStandardButtons(QtWidgets.QMessageBox.Yes
+                                                  | QtWidgets.QMessageBox.No)
+                        msgBox.setDefaultButton(QtWidgets.QMessageBox.No)
                         ret = msgBox.exec_()
-                        if ret == QtGui.QMessageBox.Yes:
+                        if ret == QtWidgets.QMessageBox.Yes:
                             self.svgdpi = 96.0
                         else:
                             self.svgdpi = 90.0
@@ -932,10 +927,10 @@ class svgHandler(xml.sax.ContentHandler):
 
             _op = '([mMlLhHvVaAcCqQsStTzZ])'
             _op2 = '([^mMlLhHvVaAcCqQsStTzZ]*)'
-            _command = '\s*?' + _op + '\s*?' + _op2 + '\s*?'
+            _command = '\\s*?' + _op + '\\s*?' + _op2 + '\\s*?'
             pathcommandsre = re.compile(_command, re.DOTALL)
 
-            _num = '[-+]?[0-9]*\.?[0-9]+'
+            _num = '[-+]?[0-9]*\\.?[0-9]+'
             _exp = '([eE][-+]?[0-9]+)?'
             _point = '(' + _num + _exp + ')'
             pointsre = re.compile(_point, re.DOTALL)
@@ -1617,8 +1612,8 @@ class svgHandler(xml.sax.ContentHandler):
             The translated matrix.
         """
         _op = '(matrix|translate|scale|rotate|skewX|skewY)'
-        _val = '\((.*?)\)'
-        _transf = _op + '\s*?' + _val
+        _val = '\\((.*?)\\)'
+        _transf = _op + '\\s*?' + _val
         transformre = re.compile(_transf, re.DOTALL)
         m = FreeCAD.Matrix()
         for transformation, arguments in transformre.findall(tr):
@@ -1705,8 +1700,8 @@ def getContents(filename, tag, stringmode=False):
     if stringmode:
         contents = filename
     else:
-        # Use the native Python open which was saved as `pythonopen`
-        f = pythonopen(filename)
+        # Use the native Python open which was saved as `pyopen`
+        f = pyopen(filename)
         contents = f.read()
         f.close()
 
@@ -1717,7 +1712,7 @@ def getContents(filename, tag, stringmode=False):
     searchpat = '<' + tag + '.*?</' + tag + '>'
     tags = re.findall(searchpat, contents)
     for t in tags:
-        tagid = re.findall('id="(.*?)"', t)
+        tagid = re.findall(r'id="(.*?)"', t)
         if tagid:
             tagid = tagid[0]
         else:
@@ -1750,8 +1745,8 @@ def open(filename):
     parser.setContentHandler(svgHandler())
     parser._cont_handler.doc = doc
 
-    # Use the native Python open which was saved as `pythonopen`
-    f = pythonopen(filename)
+    # Use the native Python open which was saved as `pyopen`
+    f = pyopen(filename)
     parser.parse(f)
     f.close()
     doc.recompute()
@@ -1789,8 +1784,8 @@ def insert(filename, docname):
     parser.setContentHandler(svgHandler())
     parser._cont_handler.doc = doc
 
-    # Use the native Python open which was saved as `pythonopen`
-    parser.parse(pythonopen(filename))
+    # Use the native Python open which was saved as `pyopen`
+    parser.parse(pyopen(filename))
     doc.recompute()
 
 
@@ -1812,8 +1807,7 @@ def export(exportList, filename):
     None
         If `exportList` doesn't have shapes to export.
     """
-    _prefs = "User parameter:BaseApp/Preferences/Mod/Draft"
-    svg_export_style = FreeCAD.ParamGet(_prefs).GetInt("svg_export_style")
+    svg_export_style = params.get_param("svg_export_style")
     if svg_export_style != 0 and svg_export_style != 1:
         _msg(translate("ImportSVG",
                        "Unknown SVG export style, switching to Translated"))
@@ -1859,8 +1853,8 @@ def export(exportList, filename):
     sizey = maxy - miny
     miny += margin
 
-    # Use the native Python open which was saved as `pythonopen`
-    svg = pythonopen(filename, 'w')
+    # Use the native Python open which was saved as `pyopen`
+    svg = pyopen(filename, 'w')
 
     # Write header.
     # We specify the SVG width and height in FreeCAD's physical units (mm),
@@ -1896,7 +1890,7 @@ def export(exportList, filename):
             # raw-style exports do not translate the sketch
             svg.write('<g id="%s" transform="scale(1,-1)">\n' % ob.Name)
 
-        svg.write(Draft.get_svg(ob))
+        svg.write(Draft.get_svg(ob, override=False))
         _label_enc = str(ob.Label.encode('utf8'))
         _label = _label_enc.replace('<', '&lt;').replace('>', '&gt;')
         # replace('"', "&quot;")
